@@ -2,9 +2,6 @@
 /*                                                                       */
 /*    This file is part of the HiGHS linear optimization suite           */
 /*                                                                       */
-/*    Written and engineered 2008-2024 by Julian Hall, Ivet Galabova,    */
-/*    Leona Gottwald and Michael Feldmeier                               */
-/*                                                                       */
 /*    Available as open-source under the MIT License                     */
 /*                                                                       */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -110,7 +107,8 @@ HighsStatus solveLp(HighsLpSolverObject& solver_object, const string message) {
             utilModelStatusToString(solver_object.model_status_).c_str(),
             solver_object.basis_.valid ? "" : "not ",
             solver_object.solution_.value_valid ? "" : "not ",
-            options.run_centring ? "off" : options.run_crossover.c_str());
+            options.run_centring ? kHighsOffString.c_str()
+                                 : options.run_crossover.c_str());
         const bool allow_simplex_cleanup =
             options.run_crossover != kHighsOffString && !options.run_centring;
         if (allow_simplex_cleanup) {
@@ -393,6 +391,7 @@ HighsStatus solveUnconstrainedLp(const HighsOptions& options, const HighsLp& lp,
   solution.value_valid = true;
   solution.dual_valid = true;
   basis.valid = true;
+  basis.useful = true;
   highs_info.basis_validity = kBasisValidityValid;
   setSolutionStatus(highs_info);
   if (highs_info.num_primal_infeasibilities) {
