@@ -2,9 +2,6 @@
 /*                                                                       */
 /*    This file is part of the HiGHS linear optimization suite           */
 /*                                                                       */
-/*    Written and engineered 2008-2024 by Julian Hall, Ivet Galabova,    */
-/*    Leona Gottwald and Michael Feldmeier                               */
-/*                                                                       */
 /*    Available as open-source under the MIT License                     */
 /*                                                                       */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -178,6 +175,36 @@ bool HighsTransformedLp::transform(std::vector<double>& vals,
       return false;
     }
 
+    // the code below uses the difference between the column upper and lower
+    // bounds as the upper bound for the slack from the variable upper bound
+    // constraint (upper[j] = ub - lb) and thus assumes that the variable upper
+    // bound constraints are tight. this assumption may not be satisfied when
+    // new bound changes were derived during cut generation and, therefore, we
+    // tighten the best variable upper bound.
+    if (bestVub[col].first != -1 &&
+        bestVub[col].second.maxValue() > ub + mip.mipdata_->feastol) {
+      bool redundant = false;
+      bool infeasible = false;
+      mip.mipdata_->implications.cleanupVub(col, bestVub[col].first,
+                                            bestVub[col].second, ub, redundant,
+                                            infeasible, false);
+    }
+
+    // the code below uses the difference between the column upper and lower
+    // bounds as the upper bound for the slack from the variable lower bound
+    // constraint (upper[j] = ub - lb) and thus assumes that the variable lower
+    // bound constraints are tight. this assumption may not be satisfied when
+    // new bound changes were derived during cut generation and, therefore, we
+    // tighten the best variable lower bound.
+    if (bestVlb[col].first != -1 &&
+        bestVlb[col].second.minValue() < lb - mip.mipdata_->feastol) {
+      bool redundant = false;
+      bool infeasible = false;
+      mip.mipdata_->implications.cleanupVlb(col, bestVlb[col].first,
+                                            bestVlb[col].second, lb, redundant,
+                                            infeasible, false);
+    }
+
     // store the old bound type so that we can restore it if the continuous
     // column is relaxed out anyways. This allows to correctly transform and
     // then untransform multiple base rows which is useful to compute cuts based
@@ -193,10 +220,18 @@ bool HighsTransformedLp::transform(std::vector<double>& vals,
       if (ub - lb <= 1.5 || boundDist[col] != 0.0 || simpleLbDist[col] == 0 ||
           simpleUbDist[col] == 0) {
         // since we skip the handling of variable bound constraints for all
-        // binary and some general-integer variables, the bound type used should
-        // be a simple lower or upper bound
-        assert(oldBoundType == BoundType::kSimpleLb ||
-               oldBoundType == BoundType::kSimpleUb);
+        // binary and some general-integer variables here, the bound type used
+        // should be a simple lower or upper bound
+        if (simpleLbDist[col] < simpleUbDist[col] - mip.mipdata_->feastol) {
+          boundTypes[col] = BoundType::kSimpleLb;
+        } else if (simpleUbDist[col] <
+                   simpleLbDist[col] - mip.mipdata_->feastol) {
+          boundTypes[col] = BoundType::kSimpleUb;
+        } else if (vals[i] > 0) {
+          boundTypes[col] = BoundType::kSimpleLb;
+        } else {
+          boundTypes[col] = BoundType::kSimpleUb;
+        }
         i++;
         continue;
       }
